==> jc-1.4.0.tar.gz: polyglot/ext/jl/Topics.c <==
// public class polyglot.ext.jl.Topics

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class eae4d0c0e8eb63da java_util_Collection
// @dep_class f3729292c2c59b2e polyglot_ext_jl_Topics
// @dep_class cf9f146bdb7bc44d polyglot_main_Report

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Collection
// @dep_header polyglot_ext_jl_Topics
// @dep_header polyglot_main_Report

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Collection.h"
#include "polyglot/ext/jl/Topics.h"
#include "polyglot/main/Report.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// public static final java.lang.String jl
static _jc_field _jc_polyglot_ext_jl_Topics$field_info$jl = {
	.name=		"jl",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_polyglot_ext_jl_Topics$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_polyglot_ext_jl_Topics$fields_struct, jl),
	.initial_value=	"jl",
};

// public static final java.lang.String qq
static _jc_field _jc_polyglot_ext_jl_Topics$field_info$qq = {
	.name=		"qq",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_polyglot_ext_jl_Topics$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_polyglot_ext_jl_Topics$fields_struct, qq),
	.initial_value=	"qq",
};

// Fields
static _jc_field *const _jc_polyglot_ext_jl_Topics$fields[] = {
	&_jc_polyglot_ext_jl_Topics$field_info$jl,
	&_jc_polyglot_ext_jl_Topics$field_info$qq
};

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// static void <clinit>()
//

static _jc_linenum _jc_polyglot_ext_jl_Topics$linenum_table$_clinit$a816641e0ba8bfef[];

static const unsigned char _jc_polyglot_ext_jl_Topics$param_ptypes$_clinit$a816641e0ba8bfef[] = { 
_JC_TYPE_VOID };

_jc_method _jc_polyglot_ext_jl_Topics$method_info$_clinit$a816641e0ba8bfef = {
	.name=			"<clinit>",
	.signature=		"()V",
	.class=			&_jc_polyglot_ext_jl_Topics$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_ext_jl_Topics$param_ptypes$_clinit$a816641e0ba8bfef,
	.signature_hash=	_JC_JLONG(0xa816641e0ba8bfef),
	.access_flags=		_JC_ACC_STATIC,
	.function=		&_jc_polyglot_ext_jl_Topics$method$_clinit$a816641e0ba8bfef,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_polyglot_ext_jl_Topics$linenum_table$_clinit$a816641e0ba8bfef
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ext_jl_Topics, _clinit$a816641e0ba8bfef);

void
_jc_polyglot_ext_jl_Topics$method$_clinit$a816641e0ba8bfef(_jc_env *const env)
{
	struct _jc_object *r0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	_JC_LINE_NUMBER(13);				// 0
	r0 = _JC_STATIC_FIELD(env, polyglot_main_Report, topics, 0);
	_JC_INVOKE_INTERFACE(env, r0, _JC_JLONG(0x831f06ee5f59c0cc), jboolean, _JC_STRING(env, "jl"));
	_JC_LINE_NUMBER(14);				// 1
	r0 = _JC_STATIC_FIELD(env, polyglot_main_Report, topics, 1);
	_JC_INVOKE_INTERFACE(env, r0, _JC_JLONG(0x831f06ee5f59c0cc), jboolean, _JC_STRING(env, "qq"));
	_JC_LINE_NUMBER(15);				// 2
	return;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_polyglot_ext_jl_Topics$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_polyglot_ext_jl_Topics$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_polyglot_ext_jl_Topics$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_polyglot_ext_jl_Topics$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_ext_jl_Topics$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_ext_jl_Topics$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_ext_jl_Topics$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ext_jl_Topics, _init$52f4ad9f2989aeee);

void
_jc_polyglot_ext_jl_Topics$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_polyglot_ext_jl_Topics$object *this)
{
	struct _jc_polyglot_ext_jl_Topics$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(8);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_polyglot_ext_jl_Topics$methods[] = {
	&_jc_polyglot_ext_jl_Topics$method_info$_clinit$a816641e0ba8bfef,
	&_jc_polyglot_ext_jl_Topics$method_info$_init$52f4ad9f2989aeee
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_polyglot_ext_jl_Topics$fields_struct _jc_polyglot_ext_jl_Topics$class_fields = { };

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_polyglot_ext_jl_Topics$instanceof_hash_bucket_46[] = {
	&_jc_polyglot_ext_jl_Topics$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_ext_jl_Topics$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_polyglot_ext_jl_Topics$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[46]=	_jc_polyglot_ext_jl_Topics$instanceof_hash_bucket_46,
	[113]=	_jc_polyglot_ext_jl_Topics$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_polyglot_ext_jl_Topics$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/util/Collection",	_JC_JLONG(0xeae4d0c0e8eb63da) },
	{ "polyglot/main/Report",	_JC_JLONG(0xcf9f146bdb7bc44d) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_polyglot_ext_jl_Topics$vtype _jc_polyglot_ext_jl_Topics$type = {
    .type= {
	.name=			"polyglot/ext/jl/Topics",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0xf3729292c2c59b2e),
		.source_file=		"Topics.java",
		.instance_size=		sizeof(_jc_polyglot_ext_jl_Topics$refs) + sizeof(_jc_polyglot_ext_jl_Topics$object),
		.num_virtual_refs=	0,
		.num_fields=		sizeof(_jc_polyglot_ext_jl_Topics$fields) / sizeof(*_jc_polyglot_ext_jl_Topics$fields),
		.fields=		_jc_polyglot_ext_jl_Topics$fields,
		.num_methods=		sizeof(_jc_polyglot_ext_jl_Topics$methods) / sizeof(*_jc_polyglot_ext_jl_Topics$methods),
		.methods=		_jc_polyglot_ext_jl_Topics$methods,
		.instanceof_hash_table=	_jc_polyglot_ext_jl_Topics$instanceof_hash_table,
		.class_fields=		&_jc_polyglot_ext_jl_Topics$class_fields,
		.num_class_depends=		sizeof(_jc_polyglot_ext_jl_Topics$class_depends) / sizeof(*_jc_polyglot_ext_jl_Topics$class_depends),
		.class_depends=		_jc_polyglot_ext_jl_Topics$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.polyglot_ext_jl_Topics= {
	},
    }
};

==> jc-1.4.5.tar.gz: polyglot/ext/jl/Topics.c <==
// public class polyglot.ext.jl.Topics

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class eae4d0c0e8eb63da java_util_Collection
// @dep_class f3729292c2c59b2e polyglot_ext_jl_Topics
// @dep_class cf9f146bdb7bc44d polyglot_main_Report

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Collection
// @dep_header polyglot_ext_jl_Topics
// @dep_header polyglot_main_Report

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Collection.h"
#include "polyglot/ext/jl/Topics.h"
#include "polyglot/main/Report.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// public static final java.lang.String jl
static _jc_field _jc_polyglot_ext_jl_Topics$field_info$jl = {
	.name=		"jl",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_polyglot_ext_jl_Topics$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_polyglot_ext_jl_Topics$fields_struct, jl),
	.initial_value=	"jl",
};

// public static final java.lang.String qq
static _jc_field _jc_polyglot_ext_jl_Topics$field_info$qq = {
	.name=		"qq",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_polyglot_ext_jl_Topics$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	_JC_ACC_PUBLIC|_JC_ACC_STATIC|_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_polyglot_ext_jl_Topics$fields_struct, qq),
	.initial_value=	"qq",
};

// Fields
static _jc_field *const _jc_polyglot_ext_jl_Topics$fields[] = {
	&_jc_polyglot_ext_jl_Topics$field_info$jl,
	&_jc_polyglot_ext_jl_Topics$field_info$qq
};

/************************************************************************
 *			      Static methods				*
 ************************************************************************/

//
// static void <clinit>()
//

static _jc_linenum _jc_polyglot_ext_jl_Topics$linenum_table$_clinit$a816641e0ba8bfef[];

static const unsigned char _jc_polyglot_ext_jl_Topics$param_ptypes$_clinit$a816641e0ba8bfef[] = { 
_JC_TYPE_VOID };

_jc_method _jc_polyglot_ext_jl_Topics$method_info$_clinit$a816641e0ba8bfef = {
	.name=			"<clinit>",
	.signature=		"()V",
	.class=			&_jc_polyglot_ext_jl_Topics$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_ext_jl_Topics$param_ptypes$_clinit$a816641e0ba8bfef,
	.signature_hash=	_JC_JLONG(0xa816641e0ba8bfef),
	.access_flags=		_JC_ACC_STATIC,
	.function=		&_jc_polyglot_ext_jl_Topics$method$_clinit$a816641e0ba8bfef,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_polyglot_ext_jl_Topics$linenum_table$_clinit$a816641e0ba8bfef
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ext_jl_Topics, _clinit$a816641e0ba8bfef);

void _JC_JCNI_ATTR
_jc_polyglot_ext_jl_Topics$method$_clinit$a816641e0ba8bfef(_jc_env *const env)
{
	struct _jc_object *r0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	_JC_LINE_NUMBER(13);				// 0
	r0 = _JC_STATIC_FIELD(env, polyglot_main_Report, topics, 0);
	_JC_INVOKE_INTERFACE(env, r0, _JC_JLONG(0x831f06ee5f59c0cc), jboolean, (_jc_env *, struct _jc_object *, struct _jc_java_lang_Object$object *), _JC_STRING(env, "jl"));
	_JC_LINE_NUMBER(14);				// 1
	r0 = _JC_STATIC_FIELD(env, polyglot_main_Report, topics, 1);
	_JC_INVOKE_INTERFACE(env, r0, _JC_JLONG(0x831f06ee5f59c0cc), jboolean, (_jc_env *, struct _jc_object *, struct _jc_java_lang_Object$object *), _JC_STRING(env, "qq"));
	_JC_LINE_NUMBER(15);				// 2
	return;
}

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>()
//

static _jc_linenum _jc_polyglot_ext_jl_Topics$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_polyglot_ext_jl_Topics$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_polyglot_ext_jl_Topics$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_polyglot_ext_jl_Topics$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_polyglot_ext_jl_Topics$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_polyglot_ext_jl_Topics$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_polyglot_ext_jl_Topics$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(polyglot_ext_jl_Topics, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_polyglot_ext_jl_Topics$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_polyglot_ext_jl_Topics$object *this)
{
	struct _jc_polyglot_ext_jl_Topics$object *r0;

	r0 = this;
	_JC_LINE_NUMBER(8);				// 0
	return;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_polyglot_ext_jl_Topics$methods[] = {
	&_jc_polyglot_ext_jl_Topics$method_info$_clinit$a816641e0ba8bfef,
	&_jc_polyglot_ext_jl_Topics$method_info$_init$52f4ad9f2989aeee
};

/************************************************************************
 *			  Class fields structure			*
 ************************************************************************/

_jc_polyglot_ext_jl_Topics$fields_struct _jc_polyglot_ext_jl_Topics$class_fields = { };

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_polyglot_ext_jl_Topics$instanceof_hash_bucket_46[] = {
	&_jc_polyglot_ext_jl_Topics$type,
	_JC_NULL
};
static _jc_type *const _jc_polyglot_ext_jl_Topics$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_polyglot_ext_jl_Topics$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[46]=	_jc_polyglot_ext_jl_Topics$instanceof_hash_bucket_46,
	[101]=	_jc_polyglot_ext_jl_Topics$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_polyglot_ext_jl_Topics$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/util/Collection",	_JC_JLONG(0xeae4d0c0e8eb63da) },
	{ "polyglot/main/Report",	_JC_JLONG(0xcf9f146bdb7bc44d) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_polyglot_ext_jl_Topics$vtype _jc_polyglot_ext_jl_Topics$type = {
    .type= {
	.name=			"polyglot/ext/jl/Topics",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		11,
		.hash=			_JC_JLONG(0xf3729292c2c59b2e),
		.source_file=		"Topics.java",
		.instance_size=		sizeof(_jc_polyglot_ext_jl_Topics$refs) + sizeof(_jc_polyglot_ext_jl_Topics$object),
		.num_virtual_refs=	0,
		.num_fields=		sizeof(_jc_polyglot_ext_jl_Topics$fields) / sizeof(*_jc_polyglot_ext_jl_Topics$fields),
		.fields=		_jc_polyglot_ext_jl_Topics$fields,
		.num_methods=		sizeof(_jc_polyglot_ext_jl_Topics$methods) / sizeof(*_jc_polyglot_ext_jl_Topics$methods),
		.methods=		_jc_polyglot_ext_jl_Topics$methods,
		.instanceof_hash_table=	_jc_polyglot_ext_jl_Topics$instanceof_hash_table,
		.class_fields=		&_jc_polyglot_ext_jl_Topics$class_fields,
		.num_class_depends=		sizeof(_jc_polyglot_ext_jl_Topics$class_depends) / sizeof(*_jc_polyglot_ext_jl_Topics$class_depends),
		.class_depends=		_jc_polyglot_ext_jl_Topics$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.polyglot_ext_jl_Topics= {
	},
    }
};
